<?php
  /**************************************************************************\
  * phpGroupWare - User manual                                               *
  * http://www.phpgroupware.org                                              *
  * --------------------------------------------                             *
  *  This program is free software; you can redistribute it and/or modify it *
  *  under the terms of the GNU General Public License as published by the   *
  *  Free Software Foundation; either version 2 of the License, or (at your  *
  *  option) any later version.                                              *
  \**************************************************************************/

	/* $Id: other.php,v 1.1 2001/05/11 02:29:15 skeeter Exp $ */

	$phpgw_flags = Array(
		'currentapp'	=> 'manual',
		'admin_header'	=> True,
		'enable_utilities_class'	=> True
	);
	$phpgw_info['flags'] = $phpgw_flags;
	include('../../../header.inc.php');
	$appname = 'admin';
?>
<img src="<?php echo $phpgw->common->image($appname,'navbar.gif'); ?>" border=0> 
<font face="<?php echo $phpgw_info['theme']['font']; ?>" size="2"><p/>
This function is usually only available to the systems administrator of the system.
Administration of all applications, user and group accounts, session logging and control.
<ul><li><b>Network news:</b><br/>
Manual update for news groups.</li><p/>
<li><b>Server information:</b><br/>
At present phpinfo of the server that is running.</li><p/>
</ul></font>
<?php $phpgw->common->phpgw_footer(); ?>
